rm(list=ls())
library(foreign)
load("~/Dropbox/Double Q Survey Replication/Data/R/panel_double_q_u.RData")

############ truncation filter #################
source("~/Dropbox/Double Q Survey Replication/Create Data Sets/R/extra/truncation filter.R")
#outputs file called "data"

############ time invariant variables #################
source("~/Dropbox/Double Q Survey Replication/Create Data Sets/R/extra/prepare time invariant variables.R")
# remove 1 respondent from Puerto Rico
data<-data[data$state!="PUERTO RICO",]

############ save individual level data #################
setwd("~/Dropbox/Double Q Survey Replication/Data/csv/")
write.csv(data,file = "panel_ind.csv")
setwd("~/Dropbox/Double Q Survey Replication/Data/Stata/")
write.dta(data, file="panel_ind.dta") 
setwd("~/Dropbox/Double Q Survey Replication/Data/R/")
save(data,file = "panel_ind.RData")

#########################################################################
######     PREPARE DATA FOR MATLAB ESTIMATION
#########################################################################
# add response patterns
source("~/Dropbox/Double Q Survey Replication/Create Data Sets/R/extra/response patterns.R")
data2<-merge(data,resp,by="prim_key")

# add id and t variables
data2<-transform(data2,id=match(prim_key,unique(prim_key)))
data2<-transform(data2,t=match(period,unique(period)))

# choose variables for Wansbeek-Kapteyn transformation
data.wk<-subset(data2,select = c("id","t","v.e","pi.e.1m.e.new","pi.e.3m.e.new","pi.e.1y.e.new",
                                "v.g","pi.e.1m.g.new","pi.e.3m.g.new","pi.e.1y.g.new",
                                "v.h","pi.e.1m.h.new","pi.e.3m.h.new","pi.e.1y.h.new"))
# choose variables for estiamtion with Fixed Effects Filtered
data.fef<-subset(data2,select = c("id","t","v.e","pi.e.1m.e.new","pi.e.3m.e.new","pi.e.1y.e.new",
                                    "v.g","pi.e.1m.g.new","pi.e.3m.g.new","pi.e.1y.g.new",
                                    "v.h","pi.e.1m.h.new","pi.e.3m.h.new","pi.e.1y.h.new",
                                    "av_age","av_inc","female","asian","black","hispaniclatino",
                                    "av_ed"))
# choose variables for estimation with MSA fixed effects
data.fef.loc<-subset(data2,select = c("id","t","v.e","pi.e.1m.e.new","pi.e.3m.e.new","pi.e.1y.e.new",
                                        "v.g","pi.e.1m.g.new","pi.e.3m.g.new","pi.e.1y.g.new",
                                        "v.h","pi.e.1m.h.new","pi.e.3m.h.new","pi.e.1y.h.new",
                                        "av_age","av_inc","female","asian","black","hispaniclatino",
                                        "av_ed","msa"))
# choose variables for estimation with Fixed Effects - Time Effects
data.fetef<-subset(data2,select = c("id","t","v.e","pi.e.1m.e.new","pi.e.3m.e.new","pi.e.1y.e.new",
                                      "v.g","pi.e.1m.g.new","pi.e.3m.g.new","pi.e.1y.g.new",
                                      "v.h","pi.e.1m.h.new","pi.e.3m.h.new","pi.e.1y.h.new",
                                      "av_age","av_inc","female","asian","black","hispaniclatino",
                                                                          "av_ed","s"))


# add MSA dummies
for(level in unique(data.fef.loc$msa)){
  data.fef.loc[paste("dummy", level, sep = "_")] <- ifelse(data.fef.loc$msa == level, 1, 0)
}
data.fef.loc$dummy_<-NULL
data.fef.loc$msa[data.fef.loc$id==906]<-"New York-Newark-Jersey City, NY-NJ-PA"
data.fef.loc$msa[data.fef.loc$id==2377]<-"Greensboro-High Point, NC"

# add response pattern dummies
data.fetef<-data.fetef[order(data.fetef$s),]
for(level in unique(data.fetef$s)){
  data.fetef[paste("dummy", level, sep = "_")] <- ifelse(data.fetef$s == level, 1, 0)
}
data.fetef$s<-NULL
data.fetef$dummy_943<-NULL

####################################################################################
############################ Wansbeek-Kapteyn Transformation
####################################################################################
rownames(data.wk)<-NULL
data.wk<-data.wk[order(data.wk$t,data.wk$id),]
setwd("~/Dropbox/Double Q Survey Replication/Data/csv/")
write.csv(data.wk, file="panel_wk.csv")

# run the file ~/Dropbox/Double Q Survey Replication/Create Data Sets/MATLAB/WK_transformation.m
# which generates the output file 
# ~/Dropbox/Double Q Survey Replication/Data/csv/WK_transformed.csv
# manually add column names to the file, the column names are provided in the file
# ~/Dropbox/Double Q Survey Replication/Data/csv/WK_colnames.csv
# then run the lines 89-108
# Note that the code below outputs a file called "panel_fetef_new.csv". 
# Given the time-consuming nature of the WK transformation, I have provided the original file
# "panel_fetef.csv", which is called by the program running the FE-TE Filtered estimation
# The code below is provided in order to show how to replicate the WK procedure.

# data.fetef<-data.fetef[order(data.fetef$t,data.fetef$id),]
# wk.data<-read.csv('~/Dropbox/Double Q Survey Replication/Data/csv/WK_transformed_with_colnames.csv')
# wk.data<-wk.data[order(wk.data$t,wk.data$id),]
# wk.data$id1<-wk.data$id
# wk.data$t1<-wk.data$t
# transformed<-subset(wk.data,select = c("id1","t1","vet" ,  "eq1mt", "eq3mt" ,"eq1yt" ,"vgt" ,  "gd1mt", "gd3mt" ,
#                                        "gd1yt" ,"vht" ,  "hs1mt", "hs3mt" ,"hs1yt",
#                                        "ve" ,  "eq1m", "eq3m" ,"eq1y" ,"vg" ,  "gd1m", "gd3m" ,
#                                        "gd1y" ,"vh" ,  "hs1m", "hs3m" ,"hs1y"))
# 
# id.vars<-subset(data.fetef,select = c("id","t"))
# z.vars<-data.fetef[,15:ncol(data.fetef)]
# data.fetef<-cbind(id.vars,transformed,z.vars)
# data.fetef$id1<-NULL
# data.fetef$t1<-NULL
# data.fetef<-data.fetef[order(data.fetef$id,data.fetef$t),]
# setwd("~/Dropbox/Double Q Survey Replication/Data/csv/")
# write.csv(data.fetef, file="panel_fetef_new.csv")
# setwd("~/Dropbox/Double Q Survey Replication/Data/Stata/")
# write.dta(data.fetef,file = "panel_fetef_new.dta")


####################################################################################
############################ FE Filtered
####################################################################################

data.fef<-data.fef[order(data.fef$id,data.fef$t),]
setwd("~/Dropbox/Double Q Survey Replication/Data/csv/")
write.csv(data.fef, file="panel_fef.csv")


# FEF with location (MSA dummies)
rownames(data.fef.loc)<-NULL
data.fef.loc<-data.fef.loc[order(data.fef.loc$id,data.fef.loc$t),]
data.fef<-data.fef[order(data.fef$id,data.fef$t),]


setwd("~/Dropbox/Double Q Survey Replication/Data/Stata/")

write.dta(data.fef.loc, file="panel_fef_loc.dta")

setwd("~/Dropbox/Double Q Survey Replication/Data/csv/")
data.fef.loc$msa<-NULL
write.csv(data.fef.loc, file="panel_fef_loc.csv")






